# QCI Connect API Client

This is a python package to interact with the [QCi Connect](https://connect.qci.dlr.de/) platform of the [German Aerospace Center (DLR)](https://www.dlr.de/). 
It also allows local testing, deployment, and interaction with the platform's compiler stack. 

## Quick start

The following steps provide a quick start on how to programmatically interact with the QCi Connect platform:

- Run `pip install qciconnect`
- Run `jupyter notebook` and navigate to _./docs/examples/example_remote.ipynb_
